@@ -1,14 +1,6 @@
 from copy import deepcopy
 from dataclasses import dataclass, fields, MISSING
-from typing import Any, Dict, Optional, Union, get_args, get_origin
-
-try:
-    # Python >= 3.10
-    from types import UnionType
-
-    UNION_TYPES = (UnionType, Union)
-except ImportError:
-    UNION_TYPES = (Union,)  # type: ignore
+from typing import Any, Dict, Optional, Union, get_args, Sequence
 
 
 @dataclass
@@ -20,7 +12,7 @@ class BaseConfig:
         def _from_dict(T: type, data: Dict[str, Union[str, BaseConfig]]):
             if data is None:
                 return None
-            T = unwrap_optional_type(T)
+            T = unwrap_type(T)
             if issubclass(T, BaseConfig):
                 return T.from_dict(data)
             return data
@@ -53,11 +45,25 @@ class BaseConfig:
         return _empty(cls, **kwargs)
 
 
-def unwrap_optional_type(T: type) -> type:
+def unwrap_type(T: type) -> type:
+    def _next(types):
+        return next(t for t in types if t is not type(None))
+
     opt_types = get_args(T)
-    if not isinstance(None, opt_types) or get_origin(T) not in UNION_TYPES:
+    if len(opt_types) == 0:
         return T
-    return next(t for t in opt_types if t is not type(None))
+
+    return unwrap_type(_next(opt_types))
+
+
+@dataclass
+class OidcMapper(BaseConfig):
+    first_name: str
+    last_name: str
+    email: str
+    affiliation: str
+    affiliation_id: str
+    additional_emails: Optional[Sequence[str]] = None
 
 
 @dataclass
@@ -65,6 +71,7 @@ class Oidc(BaseConfig):
     client_id: str
     client_secret: str
     config_url: str
+    mapper: OidcMapper
     login_redirect_url: str = "/"
     logout_redirect_url: str = "/"
 
