@@ -13,12 +13,10 @@ logger = logging.getLogger(__name__)
 def sendmail(
     subject: str,
     body: str,
-    recipients: Sequence[str],
     email_cfg: Optional[Email],
+    recipients: Optional[Sequence[str]] = None,
     **kwargs,
 ):
-    if not recipients:
-        return
     try:
         EmailMessage(
             subject=(email_cfg and email_cfg.subject_prefix or "") + subject,
