@@ -1,3 +1,4 @@
+from typing import Union
 from django.core import validators
 from django.db import models
 
@@ -46,3 +47,9 @@ def EnumField(choices, **kwargs):
     return models.CharField(
         max_length=max((len(key) for key, label_ in choices)), choices=choices, **kwargs
     )
+
+
+class EmailField(models.EmailField):
+    def pre_save(self, model_instance: models.Model, add: bool) -> Union[str, None]:
+        new_email = getattr(model_instance, self.attname)
+        return None if new_email == "" else super().pre_save(model_instance, add)
